[llvm-commits] CVS: llvm/include/llvm/CodeGen/DwarfWriter.h

Jim Laskey jlaskey at apple.com
Fri Jan 27 12:31:37 PST 2006



Changes in directory llvm/include/llvm/CodeGen:

DwarfWriter.h updated: 1.21 -> 1.22
---
Log message:

Using bit size of integers instead of ambiguous "long" et all.


---
Diffs of the changes:  (+8 -8)

 DwarfWriter.h |   16 ++++++++--------
 1 files changed, 8 insertions(+), 8 deletions(-)


Index: llvm/include/llvm/CodeGen/DwarfWriter.h
diff -u llvm/include/llvm/CodeGen/DwarfWriter.h:1.21 llvm/include/llvm/CodeGen/DwarfWriter.h:1.22
--- llvm/include/llvm/CodeGen/DwarfWriter.h:1.21	Fri Jan 27 12:32:41 2006
+++ llvm/include/llvm/CodeGen/DwarfWriter.h	Fri Jan 27 14:31:25 2006
@@ -578,21 +578,21 @@
     /// value.
     static unsigned SizeSLEB128(int Value);
     
     /// EmitByte - Emit a byte directive and value.
     ///
-    void EmitByte(int Value) const;
+    void EmitInt8(int Value) const;
 
     /// EmitShort - Emit a short directive and value.
     ///
-    void EmitShort(int Value) const;
+    void EmitInt16(int Value) const;
 
     /// EmitLong - Emit a long directive and value.
     ///
-    void EmitLong(int Value) const;
+    void EmitInt32(int Value) const;
     
     /// EmitLongLong - Emit a long long directive and value.
     ///
-    void EmitLongLong(uint64_t Value) const;
+    void EmitInt64(uint64_t Value) const;
     
     /// EmitString - Emit a string with quotes and a null terminator.
     /// Special characters are emitted properly. (Eg. '\t')
@@ -578,21 +578,21 @@
     static unsigned SizeSLEB128(int Value);
     
-    /// EmitByte - Emit a byte directive and value.
+    /// EmitInt8 - Emit a byte directive and value.
     ///
@@ -578,21 +578,21 @@
 
-    /// EmitShort - Emit a short directive and value.
+    /// EmitInt16 - Emit a short directive and value.
     ///
@@ -578,21 +578,21 @@
 
-    /// EmitLong - Emit a long directive and value.
+    /// EmitInt32 - Emit a long directive and value.
     ///
@@ -578,21 +578,21 @@
     
-    /// EmitLongLong - Emit a long long directive and value.
+    /// EmitInt64 - Emit a long long directive and value.
     ///






More information about the llvm-commits mailing list